
-- this release repeats what's deployed between 0.101 and 0.102,
-- but handles the case where a partial upgrade may have happened to 0.102
-- due to a specific concern raised for this release as a one-off.
-- repeat all the UDF upgrades for 102
CREATE OR REPLACE FUNCTION documentdb_api.list_databases(
    p_list_databases_spec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $$command_list_databases$$;
DROP FUNCTION IF EXISTS documentdb_api_internal.delete_expired_rows_for_index(
    IN collection_id bigint,
    IN index_id bigint,
    IN index_key documentdb_core.bson,
    IN index_pfe documentdb_core.bson,
    IN current_datetime bigint,
    IN index_expiry int,
    IN ttl_batch_size int,
    IN shard_id bigint);
CREATE OR REPLACE PROCEDURE documentdb_api_internal.delete_expired_rows(IN p_batch_size int default -1)
    LANGUAGE c
AS 'MODULE_PATHNAME', $procedure$delete_expired_rows$procedure$;
COMMENT ON PROCEDURE documentdb_api_internal.delete_expired_rows(int)
    IS 'Drops expired rows from applicable collections based on TTL indexes.';
DROP FUNCTION IF EXISTS documentdb_api_internal.current_op_aggregation;
CREATE OR REPLACE FUNCTION documentdb_api_internal.current_op_aggregation(p_spec documentdb_core.bson, OUT document documentdb_core.bson)
RETURNS SETOF documentdb_core.bson
 LANGUAGE c
 VOLATILE STRICT ROWS 100
AS 'MODULE_PATHNAME', $function$command_current_op_aggregation$function$;
DROP FUNCTION IF EXISTS documentdb_api_internal.current_op_worker;
CREATE OR REPLACE FUNCTION documentdb_api_internal.current_op_worker(p_spec documentdb_core.bson, OUT document documentdb_core.bson)
RETURNS documentdb_core.bson
 LANGUAGE c
 VOLATILE STRICT
AS 'MODULE_PATHNAME', $function$command_current_op_worker$function$;
DROP FUNCTION IF EXISTS documentdb_api.current_op_command;
CREATE OR REPLACE FUNCTION documentdb_api.current_op_command(p_spec documentdb_core.bson, OUT document documentdb_core.bson)
RETURNS documentdb_core.bson
LANGUAGE c
VOLATILE STRICT
AS 'MODULE_PATHNAME', $function$command_current_op$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.query_match_support(internal)
 RETURNS internal
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $$query_match_support$$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_query_match(documentdb_core.bson, documentdb_core.bson)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
 SUPPORT documentdb_api_catalog.query_match_support
AS 'MODULE_PATHNAME', $function$bson_query_match$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_true_match(documentdb_core.bson)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_true_match$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_query_match(document documentdb_core.bson, query documentdb_core.bson, variableSpec documentdb_core.bson, collationString text)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE
AS 'MODULE_PATHNAME', $function$bson_query_match$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_dollar_project(document documentdb_core.bson, pathSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_project$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_project(document documentdb_core.bson, pathSpec documentdb_core.bson, variableSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_project$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_project(document documentdb_core.bson, pathSpec documentdb_core.bson, variableSpec documentdb_core.bson, collationString text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE CALLED ON NULL INPUT
AS 'MODULE_PATHNAME', $function$bson_dollar_project$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_dollar_project_find(document documentdb_core.bson, pathSpec documentdb_core.bson, querySpec documentdb_core.bson DEFAULT NULL)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE CALLED ON NULL INPUT
AS 'MODULE_PATHNAME', $function$bson_dollar_project_find$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_project_find(document documentdb_core.bson, pathSpec documentdb_core.bson, querySpec documentdb_core.bson, letVariableSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE CALLED ON NULL INPUT
AS 'MODULE_PATHNAME', $function$bson_dollar_project_find$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_project_find(document documentdb_core.bson, pathSpec documentdb_core.bson, querySpec documentdb_core.bson, letVariableSpec documentdb_core.bson, collationString text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE CALLED ON NULL INPUT
AS 'MODULE_PATHNAME', $function$bson_dollar_project_find$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_dollar_add_fields(document documentdb_core.bson, pathSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_add_fields$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_add_fields(document documentdb_core.bson, pathSpec documentdb_core.bson, letVariableSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_add_fields$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_add_fields(document documentdb_core.bson, pathSpec documentdb_core.bson, letVariableSpec documentdb_core.bson, collationString text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE CALLED ON NULL INPUT
AS 'MODULE_PATHNAME', $function$bson_dollar_add_fields$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_dollar_set(document documentdb_core.bson, pathSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_set$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_dollar_unset(document documentdb_core.bson, pathSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_unset$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_dollar_replace_root(document documentdb_core.bson, pathSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_replace_root$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_replace_root(document documentdb_core.bson, pathSpec documentdb_core.bson, variableSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_replace_root$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_replace_root(document documentdb_core.bson, pathSpec documentdb_core.bson, variableSpec documentdb_core.bson, collationString text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE CALLED ON NULL INPUT
AS 'MODULE_PATHNAME', $function$bson_dollar_replace_root$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_dollar_facet_project(documentdb_core.bson, bool)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_facet_project$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_documents(document documentdb_core.bson, pathSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_documents$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_documents(document documentdb_core.bson, pathSpec documentdb_core.bson, overrideArray bool)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_documents$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_documents_at_path(leftDocument documentdb_core.bson, rightDocument documentdb_core.bson, fieldPath text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_documents_at_path$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_lookup_expression_eval_merge(document documentdb_core.bson, pathSpec documentdb_core.bson, variableSpec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_lookup_expression_eval_merge$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_redact(documentdb_core.bson, documentdb_core.bson, text, documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_redact$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_redact(document documentdb_core.bson, redactSpec documentdb_core.bson, redactSpecText text, variableSpec documentdb_core.bson, collationString text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE CALLED ON NULL INPUT
AS 'MODULE_PATHNAME', $function$bson_dollar_redact$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_handle_when_matched(documentdb_core.bson,documentdb_core.bson, int4, documentdb_core.bson, int4)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_handle_when_matched$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_filter_support(internal)
 RETURNS internal
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $$bson_dollar_merge_filter_support$$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_join(documentdb_core.bson,documentdb_core.bson, text)
 RETURNS BOOLEAN
 LANGUAGE c
 SUPPORT documentdb_api_internal.bson_dollar_merge_filter_support
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_join_filter$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_add_object_id(documentdb_core.bson, documentdb_core.bson, documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_add_object_id$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_fail_when_not_matched(documentdb_core.bson,text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_fail_when_not_matched$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_merge_generate_object_id(documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_merge_generate_object_id$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_extract_merge_filter(documentdb_core.bson, text)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_dollar_extract_merge_filter$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_sum_avg_transition(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_sum_avg_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_sum_avg_combine(bytea, bytea)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_sum_avg_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_sum_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_sum_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_avg_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_avg_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_min_max_final(documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_min_max_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_max_transition(documentdb_core.bson, documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_max_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_min_transition(documentdb_core.bson, documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_min_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_min_combine(documentdb_core.bson, documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_min_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_max_combine(documentdb_core.bson, documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_max_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_first_transition(bytea, documentdb_core.bson, documentdb_core.bson[])
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_first_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_last_transition(bytea, documentdb_core.bson, documentdb_core.bson[])
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_last_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_first_transition_on_sorted(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_first_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_last_transition_on_sorted(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_last_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_first_last_final_on_sorted(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_first_last_final_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_first_combine(bytea, bytea)
 RETURNS bytea
 LANGUAGE c
 STABLE STRICT
AS 'MODULE_PATHNAME', $function$bson_first_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_last_combine(bytea, bytea)
 RETURNS bytea
 LANGUAGE c
 STABLE STRICT
AS 'MODULE_PATHNAME', $function$bson_last_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_first_last_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_first_last_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_array_agg_transition(bytea, documentdb_core.bson, text)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_array_agg_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_array_agg_transition(bytea, documentdb_core.bson, text, boolean)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_array_agg_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_array_agg_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_array_agg_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_object_agg_transition(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_object_agg_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_object_agg_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_object_agg_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_firstn_transition(bytea, documentdb_core.bson, bigint, documentdb_core.bson[])
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_firstn_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_lastn_transition(bytea, documentdb_core.bson, bigint, documentdb_core.bson[])
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_lastn_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_firstn_combine(bytea, bytea)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_firstn_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_lastn_combine(bytea, bytea)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_lastn_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_firstn_lastn_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_firstn_lastn_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_firstn_transition_on_sorted(bytea, documentdb_core.bson, bigint)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_firstn_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_lastn_transition_on_sorted(bytea, documentdb_core.bson, bigint)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_lastn_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_firstn_lastn_final_on_sorted(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_firstn_lastn_final_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_add_to_set_transition(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_add_to_set_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_add_to_set_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_add_to_set_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_merge_objects_transition_on_sorted(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_merge_objects_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_merge_objects_transition(bytea, documentdb_core.bson, bigint, documentdb_core.bson[], documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_merge_objects_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_merge_objects_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_merge_objects_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_std_dev_pop_samp_transition(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_std_dev_pop_samp_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_std_dev_pop_samp_combine(bytea, bytea)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_std_dev_pop_samp_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_std_dev_pop_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_std_dev_pop_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_std_dev_samp_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_std_dev_samp_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_first_transition(bytea, documentdb_core.bson, documentdb_core.bson[], documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_first_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_last_transition(bytea, documentdb_core.bson, documentdb_core.bson[], documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_last_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_firstn_transition(bytea, documentdb_core.bson, bigint, documentdb_core.bson[], documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_firstn_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_lastn_transition(bytea, documentdb_core.bson, bigint, documentdb_core.bson[], documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_lastn_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_maxn_transition(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_maxn_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_minn_transition(bytea, documentdb_core.bson)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_minn_transition$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_maxminn_final(bytea)
 RETURNS documentdb_core.bson
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_maxminn_final$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_maxminn_combine(bytea, bytea)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_maxminn_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_first_transition_on_sorted(bytea, documentdb_core.bson, documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_first_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_last_transition_on_sorted(bytea, documentdb_core.bson, documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_last_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_firstn_transition_on_sorted(bytea, documentdb_core.bson, bigint, documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_firstn_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_lastn_transition_on_sorted(bytea, documentdb_core.bson, bigint, documentdb_core.bson DEFAULT NULL)
 RETURNS bytea
 LANGUAGE c
 STABLE
AS 'MODULE_PATHNAME', $function$bson_lastn_transition_on_sorted$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.tdigest_add_double(internal, documentdb_core.bson, int4, documentdb_core.bson)
 RETURNS internal
 LANGUAGE c
 IMMUTABLE
AS 'MODULE_PATHNAME', $function$tdigest_add_double$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.tdigest_add_double_array(internal, documentdb_core.bson, int4, documentdb_core.bson)
 RETURNS internal
 LANGUAGE c
 IMMUTABLE
AS 'MODULE_PATHNAME', $function$tdigest_add_double_array$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.tdigest_percentile(internal)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE
AS 'MODULE_PATHNAME', $function$tdigest_percentile$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.tdigest_array_percentiles(internal)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE
AS 'MODULE_PATHNAME', $function$tdigest_array_percentiles$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.tdigest_combine(internal, internal)
 RETURNS internal
 LANGUAGE c
 IMMUTABLE
AS 'MODULE_PATHNAME', $function$tdigest_combine$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.tdigest_serial(internal)
 RETURNS bytea
 LANGUAGE c
 IMMUTABLE STRICT
AS 'MODULE_PATHNAME', $function$tdigest_serial$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.tdigest_deserial(bytea, internal)
 RETURNS internal
 LANGUAGE c
 IMMUTABLE STRICT
AS 'MODULE_PATHNAME', $function$tdigest_deserial$function$;
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONSUM(documentdb_core.bson)
(
    SFUNC = documentdb_api_catalog.bson_sum_avg_transition,
    FINALFUNC = documentdb_api_catalog.bson_sum_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_sum_avg_combine,
    mstype = bytea,
    MSFUNC = documentdb_api_catalog.bson_sum_avg_transition,
    MFINALFUNC = documentdb_api_catalog.bson_sum_final,
    MINVFUNC = documentdb_api_internal.bson_sum_avg_minvtransition,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONAVERAGE(documentdb_core.bson)
(
    SFUNC = documentdb_api_catalog.bson_sum_avg_transition,
    FINALFUNC = documentdb_api_catalog.bson_avg_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_sum_avg_combine,
    mstype = bytea,
    MSFUNC = documentdb_api_catalog.bson_sum_avg_transition,
    MFINALFUNC = documentdb_api_catalog.bson_avg_final,
    MINVFUNC = documentdb_api_internal.bson_sum_avg_minvtransition,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONMAX(documentdb_core.bson)
(
    SFUNC = documentdb_api_catalog.bson_max_transition,
    FINALFUNC = documentdb_api_catalog.bson_min_max_final,
    stype = documentdb_core.bson,
    COMBINEFUNC = documentdb_api_catalog.bson_max_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONMIN(documentdb_core.bson)
(
    SFUNC = documentdb_api_catalog.bson_min_transition,
    FINALFUNC = documentdb_api_catalog.bson_min_max_final,
    stype = documentdb_core.bson,
    COMBINEFUNC = documentdb_api_catalog.bson_min_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONFIRST(documentdb_core.bson, documentdb_core.bson[])
(
    SFUNC = documentdb_api_catalog.bson_first_transition,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_first_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONLAST(documentdb_core.bson, documentdb_core.bson[])
(
    SFUNC = documentdb_api_catalog.bson_last_transition,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_last_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONFIRSTONSORTED(documentdb_core.bson)
(
    SFUNC = documentdb_api_catalog.bson_first_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONLASTONSORTED(documentdb_core.bson)
(
    SFUNC = documentdb_api_catalog.bson_last_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONFIRSTN(documentdb_core.bson, bigint, documentdb_core.bson[])
(
    SFUNC = documentdb_api_catalog.bson_firstn_transition,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_firstn_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONLASTN(documentdb_core.bson, bigint, documentdb_core.bson[])
(
    SFUNC = documentdb_api_catalog.bson_lastn_transition,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_lastn_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONFIRSTNONSORTED(documentdb_core.bson, bigint)
(
    SFUNC = documentdb_api_catalog.bson_firstn_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSONLASTNONSORTED(documentdb_core.bson, bigint)
(
    SFUNC = documentdb_api_catalog.bson_lastn_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSON_ARRAY_AGG(documentdb_core.bson, text)
(
    SFUNC = documentdb_api_catalog.bson_array_agg_transition,
    FINALFUNC = documentdb_api_catalog.bson_array_agg_final,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSON_OBJECT_AGG(documentdb_core.bson)
(
    SFUNC = documentdb_api_catalog.bson_object_agg_transition,
    FINALFUNC = documentdb_api_catalog.bson_object_agg_final,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_catalog.BSON_ARRAY_AGG(documentdb_core.bson, text, boolean)
(
    SFUNC = documentdb_api_catalog.bson_array_agg_transition,
    FINALFUNC = documentdb_api_catalog.bson_array_agg_final,
    stype = bytea,
    mstype = bytea,
    MSFUNC = documentdb_api_catalog.bson_array_agg_transition,
    MFINALFUNC = documentdb_api_catalog.bson_array_agg_final,
    MINVFUNC = documentdb_api_internal.bson_array_agg_minvtransition,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSON_ADD_TO_SET(documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_add_to_set_transition,
    FINALFUNC = documentdb_api_internal.bson_add_to_set_final,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSON_MERGE_OBJECTS_ON_SORTED(documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_merge_objects_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_object_agg_final,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSON_MERGE_OBJECTS(documentdb_core.bson, bigint, documentdb_core.bson[], documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_merge_objects_transition,
    FINALFUNC = documentdb_api_internal.bson_merge_objects_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_firstn_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONSTDDEVPOP(documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_std_dev_pop_samp_transition,
    FINALFUNC = documentdb_api_internal.bson_std_dev_pop_final,
    MSFUNC = documentdb_api_internal.bson_std_dev_pop_samp_transition,
    MFINALFUNC = documentdb_api_internal.bson_std_dev_pop_winfunc_final,
    MINVFUNC = documentdb_api_internal.bson_std_dev_pop_samp_winfunc_invtransition,
    stype = bytea,
    mstype = bytea,
    COMBINEFUNC = documentdb_api_internal.bson_std_dev_pop_samp_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONSTDDEVSAMP(documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_std_dev_pop_samp_transition,
    FINALFUNC = documentdb_api_internal.bson_std_dev_samp_final,
    MSFUNC = documentdb_api_internal.bson_std_dev_pop_samp_transition,
    MFINALFUNC = documentdb_api_internal.bson_std_dev_samp_winfunc_final,
    MINVFUNC = documentdb_api_internal.bson_std_dev_pop_samp_winfunc_invtransition,
    stype = bytea,
    mstype = bytea,
    COMBINEFUNC = documentdb_api_internal.bson_std_dev_pop_samp_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONFIRST(documentdb_core.bson, documentdb_core.bson[], documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_first_transition,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_first_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONLAST(documentdb_core.bson, documentdb_core.bson[], documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_last_transition,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_last_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONFIRSTN(documentdb_core.bson, bigint, documentdb_core.bson[], documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_firstn_transition,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_firstn_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONLASTN(documentdb_core.bson, bigint, documentdb_core.bson[], documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_lastn_transition,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_catalog.bson_lastn_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONMAXN(documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_maxn_transition,
    FINALFUNC = documentdb_api_internal.bson_maxminn_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_internal.bson_maxminn_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONMINN(documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_minn_transition,
    FINALFUNC = documentdb_api_internal.bson_maxminn_final,
    stype = bytea,
    COMBINEFUNC = documentdb_api_internal.bson_maxminn_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONFIRSTONSORTED(documentdb_core.bson, documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_first_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONLASTONSORTED(documentdb_core.bson, documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_last_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_first_last_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONFIRSTNONSORTED(documentdb_core.bson, bigint, documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_firstn_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONLASTNONSORTED(documentdb_core.bson, bigint, documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.bson_lastn_transition_on_sorted,
    FINALFUNC = documentdb_api_catalog.bson_firstn_lastn_final_on_sorted,
    stype = bytea,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONPERCENTILE(documentdb_core.bson, int4, documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.tdigest_add_double_array,
    stype = internal,
    FINALFUNC = documentdb_api_internal.tdigest_array_percentiles,
    SERIALFUNC = documentdb_api_internal.tdigest_serial,
    DESERIALFUNC = documentdb_api_internal.tdigest_deserial,
    COMBINEFUNC = documentdb_api_internal.tdigest_combine,
    PARALLEL = SAFE
);
CREATE OR REPLACE AGGREGATE documentdb_api_internal.BSONMEDIAN(documentdb_core.bson, int4, documentdb_core.bson)
(
    SFUNC = documentdb_api_internal.tdigest_add_double,
    stype = internal,
    FINALFUNC = documentdb_api_internal.tdigest_percentile,
    SERIALFUNC = documentdb_api_internal.tdigest_serial,
    DESERIALFUNC = documentdb_api_internal.tdigest_deserial,
    COMBINEFUNC = documentdb_api_internal.tdigest_combine,
    PARALLEL = SAFE
);
DROP FUNCTION IF EXISTS documentdb_api_internal.apply_extension_data_table_upgrade;
CREATE OR REPLACE FUNCTION documentdb_api_internal.apply_extension_data_table_upgrade(int4, int4, int4)
RETURNS void
LANGUAGE c
STRICT
AS 'MODULE_PATHNAME', $function$apply_extension_data_table_upgrade$function$;
COMMENT ON FUNCTION documentdb_api_internal.apply_extension_data_table_upgrade(int4, int4, int4)
    IS 'alter creation time column';
-- Schedule TTL Cron job to prune TTL indexes on every documentdb instance (This is idempotent and will not create duplicates)
DO LANGUAGE plpgsql $cmd$
BEGIN
    IF NOT EXISTS(SELECT 1 FROM cron.job where jobname = 'documentdb_ttl_task') THEN
        PERFORM cron.schedule('documentdb_ttl_task', '* * * * *', $$CALL documentdb_api_internal.delete_expired_rows();$$);
    END IF;
END;
$cmd$;
-- drop the aggregates for $out. These are unused anyway and idempotent
DROP AGGREGATE IF EXISTS documentdb_api_catalog.BSON_OUT(documentdb_core.bson, text, text, text, text);
DROP FUNCTION IF EXISTS documentdb_api_catalog.bson_out_transition;
DROP FUNCTION IF EXISTS documentdb_api_catalog.bson_out_final;
-- ALTER creation_time column for all the documentdb tables
SELECT documentdb_api_internal.apply_extension_data_table_upgrade(0, 102, 1);
-- now handle the upgrade for bsonindexbounds
DO LANGUAGE plpgsql $cmd$
BEGIN
    IF NOT EXISTS(SELECT 1 FROM pg_type where typname = 'bsonindexbounds' AND typnamespace = 'documentdb_api_internal'::regnamespace) THEN
CREATE TYPE documentdb_api_internal.bsonindexbounds;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonindexbounds_in(cstring)
 RETURNS documentdb_api_internal.bsonindexbounds
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_in$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonindexbounds_out(documentdb_api_internal.bsonindexbounds)
 RETURNS cstring
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_out$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonindexbounds_send(documentdb_api_internal.bsonindexbounds)
 RETURNS bytea
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_send$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonindexbounds_recv(internal)
 RETURNS documentdb_api_internal.bsonindexbounds
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_recv$function$;
CREATE TYPE documentdb_api_internal.bsonindexbounds (
    input = documentdb_api_internal.bsonindexbounds_in,
    output = documentdb_api_internal.bsonindexbounds_out,
    send = documentdb_api_internal.bsonindexbounds_send,
    receive = documentdb_api_internal.bsonindexbounds_recv,
    alignment = int4,
    storage = extended
);
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_eq(documentdb_core.bson,documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
 SUPPORT documentdb_api_catalog.dollar_support
AS 'MODULE_PATHNAME', $function$bson_dollar_eq$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_lt(documentdb_core.bson,documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
 SUPPORT documentdb_api_catalog.dollar_support
AS 'MODULE_PATHNAME', $function$bson_dollar_lt$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_lte(documentdb_core.bson,documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
 SUPPORT documentdb_api_catalog.dollar_support
AS 'MODULE_PATHNAME', $function$bson_dollar_lte$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_gt(documentdb_core.bson,documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
 SUPPORT documentdb_api_catalog.dollar_support
AS 'MODULE_PATHNAME', $function$bson_dollar_gt$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_dollar_gte(documentdb_core.bson,documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
 SUPPORT documentdb_api_catalog.dollar_support
AS 'MODULE_PATHNAME', $function$bson_dollar_gte$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonquery_eq(documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bsonquery_equal$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonquery_lt(documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bsonquery_lt$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonquery_lte(documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bsonquery_lte$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonquery_gt(documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bsonquery_gt$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bsonquery_gte(documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bsonquery_gte$function$;
CREATE OPERATOR documentdb_api_internal.##= (
    LEFTARG = documentdb_core.bson,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bson_dollar_eq
);
CREATE OPERATOR documentdb_api_internal.##> (
    LEFTARG = documentdb_core.bson,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bson_dollar_gt
);
CREATE OPERATOR documentdb_api_internal.##>= (
    LEFTARG = documentdb_core.bson,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bson_dollar_gte
);
CREATE OPERATOR documentdb_api_internal.##< (
    LEFTARG = documentdb_core.bson,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bson_dollar_lt
);
CREATE OPERATOR documentdb_api_internal.##<= (
    LEFTARG = documentdb_core.bson,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bson_dollar_lte
);
CREATE OPERATOR documentdb_api_internal.< (
    LEFTARG = documentdb_core.bsonquery,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bsonquery_lt
);
CREATE OPERATOR documentdb_api_internal.<= (
    LEFTARG = documentdb_core.bsonquery,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bsonquery_lte
);
CREATE OPERATOR documentdb_api_internal.> (
    LEFTARG = documentdb_core.bsonquery,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bsonquery_gt
);
CREATE OPERATOR documentdb_api_internal.>= (
    LEFTARG = documentdb_core.bsonquery,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bsonquery_gte
);
CREATE OPERATOR documentdb_api_internal.= (
    LEFTARG = documentdb_core.bsonquery,
    RIGHTARG = documentdb_api_internal.bsonindexbounds,
    PROCEDURE = documentdb_api_internal.bsonquery_eq
);
CREATE OPERATOR FAMILY documentdb_api_internal.bsonindexbounds_pfe_btree_family USING btree;
-- This is the comparison clause for predicate proof.
CREATE OPERATOR CLASS documentdb_api_internal.bsonquery_indexbounds_btree_pfe_compare_ops
    FOR TYPE documentdb_core.bsonquery USING btree FAMILY documentdb_api_internal.bsonindexbounds_pfe_btree_family AS
        OPERATOR 1 documentdb_api_internal.< (documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds),
        OPERATOR 2 documentdb_api_internal.<= (documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds),
        OPERATOR 3 documentdb_api_internal.= (documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds),
        OPERATOR 4 documentdb_api_internal.>= (documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds),
        OPERATOR 5 documentdb_api_internal.> (documentdb_core.bsonquery, documentdb_api_internal.bsonindexbounds);
-- This is what's on the index PFE
CREATE OPERATOR CLASS documentdb_api_internal.bson_btree_pfe_base_ops
    FOR TYPE documentdb_core.bson USING btree FAMILY documentdb_api_internal.bsonindexbounds_pfe_btree_family AS
        OPERATOR 1 documentdb_api_catalog.#< (documentdb_core.bson, documentdb_core.bsonquery),
        OPERATOR 2 documentdb_api_catalog.#<= (documentdb_core.bson, documentdb_core.bsonquery),
        OPERATOR 3 documentdb_api_catalog.#= (documentdb_core.bson, documentdb_core.bsonquery),
        OPERATOR 4 documentdb_api_catalog.#>= (documentdb_core.bson, documentdb_core.bsonquery),
        OPERATOR 5 documentdb_api_catalog.#> (documentdb_core.bson, documentdb_core.bsonquery);
-- This is the query clause that's created
CREATE OPERATOR CLASS documentdb_api_internal.bsonindexbounds_btree_pfe_ops
    FOR TYPE documentdb_core.bson USING btree FAMILY documentdb_api_internal.bsonindexbounds_pfe_btree_family AS
        OPERATOR 1 documentdb_api_internal.##< (documentdb_core.bson, documentdb_api_internal.bsonindexbounds),
        OPERATOR 2 documentdb_api_internal.##<= (documentdb_core.bson, documentdb_api_internal.bsonindexbounds),
        OPERATOR 3 documentdb_api_internal.##= (documentdb_core.bson, documentdb_api_internal.bsonindexbounds),
        OPERATOR 4 documentdb_api_internal.##>= (documentdb_core.bson, documentdb_api_internal.bsonindexbounds),
        OPERATOR 5 documentdb_api_internal.##> (documentdb_core.bson, documentdb_api_internal.bsonindexbounds);
    END IF;
END;
$cmd$;
